@@ -30,37 +30,39 @@
 // Check to ensure this file is included in Joomla!
 defined('_JEXEC') or die('Restricted access');
 
-$text = ($this->task == 'edit' ? JText::_('EDIT') : JText::_('NEW'));
+$text = ($this->task == 'edit' ? JText::_('JACTION_EDIT') : JText::_('JACTION_CREATE'));
 
 $canDo = CoursesHelper::getActions();
 
 JToolBarHelper::title(JText::_('COM_COURSES').': ' . $text, 'courses.png');
-if ($canDo->get('core.edit')) 
+if ($canDo->get('core.edit'))
 {
 	JToolBarHelper::apply();
 	JToolBarHelper::save();
 	JToolBarHelper::spacer();
 }
 JToolBarHelper::cancel();
+JToolBarHelper::spacer();
+JToolBarHelper::help('course');
 
 $this->css();
 ?>
 <script type="text/javascript">
-function submitbutton(pressbutton) 
+function submitbutton(pressbutton)
 {
 	var form = document.adminForm;
-	
+
 	if (pressbutton == 'cancel') {
 		submitform(pressbutton);
 		return;
 	}
-	
+
 	// form field validation
 	if (document.getElementById('field-title').value == '') {
-		alert('<?php echo JText::_('COM_COURSES_ERROR_MISSING_INFORMATION'); ?>');
-	//} else if (form.getElementById('field-alias').value == '') {
-	//	alert('<?php echo JText::_('COM_COURSES_ERROR_MISSING_INFORMATION'); ?>');
+		alert('<?php echo JText::_('COM_COURSES_ERROR_MISSING_TITLE'); ?>');
 	} else {
+		<?php echo JFactory::getEditor()->save('text'); ?>
+
 		submitform(pressbutton);
 	}
 }
@@ -71,127 +73,108 @@ function submitbutton(pressbutton)
 <form action="index.php" method="post" name="adminForm" id="item-form">
 	<div class="col width-60 fltlft">
 		<fieldset class="adminform">
-			<legend><span><?php echo JText::_('COM_COURSES_DETAILS'); ?></span></legend>
-			
+			<legend><span><?php echo JText::_('JDETAILS'); ?></span></legend>
+
 			<input type="hidden" name="fields[id]" value="<?php echo $this->row->get('id'); ?>" />
 			<input type="hidden" name="option" value="<?php echo $this->option; ?>" />
 			<input type="hidden" name="controller" value="<?php echo $this->controller; ?>">
 			<input type="hidden" name="task" value="save" />
-			
-			<table class="admintable">
-				<tbody>
-					<tr>
-						<td class="key"><label for="field-group_id"><?php echo JText::_('Group'); ?>:</label></td>
-						<td>
-							<select name="fields[group_id]" id="field-group_id">
-								<option value="0"<?php if (!$this->row->get('group_id')) { echo ' selected="selected"'; } ?>><?php echo JText::_('[none]'); ?></option>
-							<?php
-							$filters = array(
-								'authorized' => 'admin',
-								'fields'     => array('cn', 'description', 'published', 'gidNumber', 'type'),
-								'type'       => array(1, 3),
-								'sortby'     => 'description'
-							);
-							$groups = \Hubzero\User\Group::find($filters);
-							if ($groups)
-							{
-								foreach ($groups as $group)
-								{
-									?>
-									<option value="<?php echo $group->gidNumber; ?>"<?php if ($group->gidNumber == $this->row->get('group_id')) { echo ' selected="selected"'; } ?>><?php echo $this->escape($group->description); ?> (<?php echo $this->escape($group->cn); ?>)</option>
-									<?php 
-								}
-							}
+
+			<div class="input-wrap">
+				<label for="field-group_id"><?php echo JText::_('COM_COURSES_FIELD_GROUP'); ?>:</label><br />
+				<select name="fields[group_id]" id="field-group_id">
+					<option value="0"<?php if (!$this->row->get('group_id')) { echo ' selected="selected"'; } ?>><?php echo JText::_('COM_COURSES_NONE'); ?></option>
+					<?php
+					$filters = array(
+						'authorized' => 'admin',
+						'fields'     => array('cn', 'description', 'published', 'gidNumber', 'type'),
+						'type'       => array(1, 3),
+						'sortby'     => 'description'
+					);
+					$groups = \Hubzero\User\Group::find($filters);
+					if ($groups)
+					{
+						foreach ($groups as $group)
+						{
 							?>
-							</select>
-						</td>
-					</tr>
-					<tr>
-						<td class="key"><label for="field-alias"><?php echo JText::_('Alias'); ?>:</label></td>
-						<td>
-							<input type="text" name="fields[alias]" id="field-alias" value="<?php echo $this->escape(stripslashes($this->row->get('alias'))); ?>" size="50" />
-							<span class="hint"><?php echo JText::_('Alpha-numeric characters only. If left blank, alias will be generated from the title.'); ?></span>
-						</td>
-					</tr>
-					<tr>
-						<td class="key"><label for="field-title"><?php echo JText::_('COM_COURSES_TITLE'); ?>:</label></td>
-						<td><input type="text" name="fields[title]" id="field-title" value="<?php echo $this->escape(stripslashes($this->row->get('title'))); ?>" size="50" /></td>
-					</tr>
-					<tr>
-						<td class="key" valign="top"><label for="field-blurb"><?php echo JText::_('Blurb'); ?>:</label></td>
-						<td>
-							<textarea name="fields[blurb]" id="field-blurb" cols="40" rows="3"><?php echo $this->escape(stripslashes($this->row->get('blurb'))); ?></textarea>
-							<span class="hint"><?php echo JText::_('This is a short sentence or two for the catalog.'); ?></span>
-						</td>
-					</tr>
-					<tr>
-						<td class="key" valign="top"><label for="field-description"><?php echo JText::_('Description'); ?>:</label></td>
-						<td>
-							<textarea name="fields[description]" id="field-description" cols="40" rows="15"><?php echo $this->escape($this->row->description('raw')); ?></textarea>
-							<span class="hint"><?php echo JText::_('This is a longer, detailed description of the course.'); ?></span>
-						</td>
-					</tr>
-					<tr>
-						<td class="key" valign="top"><label for="field-tags"><?php echo JText::_('Tags'); ?>:</label></td>
-						<td>
-							<textarea name="tags" id="field-tags" cols="40" rows="3"><?php echo $this->escape(stripslashes($this->row->tags('string'))); ?></textarea>
-						</td>
-					</tr>
-				</tbody>
-			</table>
+							<option value="<?php echo $group->gidNumber; ?>"<?php if ($group->gidNumber == $this->row->get('group_id')) { echo ' selected="selected"'; } ?>><?php echo $this->escape($group->description); ?> (<?php echo $this->escape($group->cn); ?>)</option>
+							<?php
+						}
+					}
+					?>
+				</select>
+			</div>
+			<div class="input-wrap" data-hint="<?php echo JText::_('COM_COURSES_FIELD_ALIAS_HINT'); ?>">
+				<label for="field-alias"><?php echo JText::_('COM_COURSES_FIELD_ALIAS'); ?>:</label><br />
+				<input type="text" name="fields[alias]" id="field-alias" value="<?php echo $this->escape($this->row->get('alias')); ?>" size="50" />
+				<span class="hint"><?php echo JText::_('COM_COURSES_FIELD_ALIAS_HINT'); ?></span>
+			</div>
+			<div class="input-wrap">
+				<label for="field-title"><?php echo JText::_('COM_COURSES_FIELD_TITLE'); ?>: <span class="required"><?php echo JText::_('JOPTION_REQUIRED'); ?></span></label><br />
+				<input type="text" name="fields[title]" id="field-title" value="<?php echo $this->escape($this->row->get('title')); ?>" size="50" />
+			</div>
+			<div class="input-wrap" data-hint="<?php echo JText::_('COM_COURSES_FIELD_BLURB_HINT'); ?>">
+				<label for="field-blurb"><?php echo JText::_('COM_COURSES_FIELD_BLURB'); ?>:</label><br />
+				<textarea name="fields[blurb]" id="field-blurb" cols="40" rows="3"><?php echo $this->escape($this->row->get('blurb')); ?></textarea>
+				<span class="hint"><?php echo JText::_('COM_COURSES_FIELD_BLURB_HINT'); ?></span>
+			</div>
+			<div class="input-wrap" data-hint="<?php echo JText::_('COM_COURSES_FIELD_DESCRIPTION_HINT'); ?>">
+				<label for="field-description"><?php echo JText::_('COM_COURSES_FIELD_DESCRIPTION'); ?>:</label><br />
+				<?php echo JFactory::getEditor()->display('fields[description]', $this->escape($this->row->description('raw')), '', '', 40, 15, false, 'field-description'); ?>
+				<span class="hint"><?php echo JText::_('COM_COURSES_FIELD_DESCRIPTION_HINT'); ?></span>
+			</div>
+			<div class="input-wrap" data-hint="<?php echo JText::_('COM_COURSES_FIELD_TAGS_HINT'); ?>">
+				<label for="field-tags"><?php echo JText::_('COM_COURSES_FIELD_TAGS'); ?>:</label><br />
+				<textarea name="tags" id="field-tags" cols="40" rows="3"><?php echo $this->escape(stripslashes($this->row->tags('string'))); ?></textarea>
+				<span class="hint"><?php echo JText::_('COM_COURSES_FIELD_TAGS_HINT'); ?></span>
+			</div>
 		</fieldset>
 
 		<fieldset class="adminform">
-			<legend><span><?php echo JText::_('Managers'); ?></span></legend>
+			<legend><span><?php echo JText::_('COM_COURSES_FIELDSET_MANAGERS'); ?></span></legend>
 		<?php if ($this->row->get('id')) { ?>
-			<iframe width="100%" height="400" name="managers" id="managers" frameborder="0" src="index.php?option=<?php echo $this->option; ?>&amp;controller=managers&amp;tmpl=component&amp;id=<?php echo $this->row->get('id'); ?>"></iframe>
+			<iframe height="400" name="managers" id="managers" src="index.php?option=<?php echo $this->option; ?>&amp;controller=managers&amp;tmpl=component&amp;id=<?php echo $this->row->get('id'); ?>"></iframe>
 		<?php } else { ?>
-			<p><?php echo JText::_('Course must be saved before managers can be added.'); ?></p>
+			<p class="warning"><?php echo JText::_('COM_COURSES_FIELDSET_MANAGERS_WARNING'); ?></p>
 		<?php } ?>
 		</fieldset>
 	</div>
 	<div class="col width-40 fltrt">
-		<table class="meta" summary="<?php echo JText::_('COM_COURSES_META_SUMMARY'); ?>">
+		<table class="meta">
 			<tbody>
 				<tr>
-					<th><?php echo JText::_('Course ID'); ?></th>
+					<th><?php echo JText::_('COM_COURSES_FIELD_ID'); ?></th>
 					<td><?php echo $this->escape($this->row->get('id')); ?></td>
 				</tr>
 			<?php if ($this->row->get('created')) { ?>
 				<tr>
-					<th><?php echo JText::_('Created'); ?></th>
+					<th><?php echo JText::_('COM_COURSES_FIELD_CREATED'); ?></th>
 					<td><?php echo $this->escape($this->row->get('created')); ?></td>
 				</tr>
 			<?php } ?>
 			<?php if ($this->row->get('created_by')) { ?>
 				<tr>
-					<th><?php echo JText::_('Creator'); ?></th>
-					<td><?php 
+					<th><?php echo JText::_('COM_COURSES_FIELD_CREATOR'); ?></th>
+					<td><?php
 					$creator = JUser::getInstance($this->row->get('created_by'));
 					echo $this->escape(stripslashes($creator->get('name'))); ?></td>
 				</tr>
 			<?php } ?>
 			</tbody>
 		</table>
-		
+
 		<fieldset class="adminform">
-			<legend><span><?php echo JText::_('Publishing'); ?></span></legend>
-			
-			<table class="admintable">
-				<tbody>
-					<tr>
-						<td class="key" valign="top"><label for="field-state"><?php echo JText::_('State'); ?>:</label></td>
-						<td>
-							<select name="fields[state]" id="field-state">
-								<option value="0"<?php if ($this->row->get('state') == 0) { echo ' selected="selected"'; } ?>><?php echo JText::_('Unpublished'); ?></option>
-								<option value="1"<?php if ($this->row->get('state') == 1) { echo ' selected="selected"'; } ?>><?php echo JText::_('Published'); ?></option>
-								<option value="3"<?php if ($this->row->get('state') == 3) { echo ' selected="selected"'; } ?>><?php echo JText::_('Draft'); ?></option>
-								<option value="2"<?php if ($this->row->get('state') == 2) { echo ' selected="selected"'; } ?>><?php echo JText::_('Deleted'); ?></option>
-							</select>
-						</td>
-					</tr>
-				</tbody>
-			</table>
+			<legend><span><?php echo JText::_('COM_COURSES_FIELDSET_PUBLISHING'); ?></span></legend>
+
+			<div class="input-wrap">
+				<label for="field-state"><?php echo JText::_('COM_COURSES_FIELD_STATE'); ?>:</label><br />
+				<select name="fields[state]" id="field-state">
+					<option value="0"<?php if ($this->row->get('state') == 0) { echo ' selected="selected"'; } ?>><?php echo JText::_('COM_COURSES_UNPUBLISHED'); ?></option>
+					<option value="1"<?php if ($this->row->get('state') == 1) { echo ' selected="selected"'; } ?>><?php echo JText::_('COM_COURSES_PUBLISHED'); ?></option>
+					<option value="3"<?php if ($this->row->get('state') == 3) { echo ' selected="selected"'; } ?>><?php echo JText::_('COM_COURSES_DRAFT'); ?></option>
+					<option value="2"<?php if ($this->row->get('state') == 2) { echo ' selected="selected"'; } ?>><?php echo JText::_('COM_COURSES_TRASHED'); ?></option>
+				</select>
+			</div>
 		</fieldset>
 
 		<?php
@@ -209,13 +192,13 @@ function submitbutton(pressbutton)
 						JPATH_ROOT . DS . 'plugins' . DS . 'courses' . DS . $plugin['name'] . DS . $plugin['name'] . '.xml'
 					);
 					$out = $param->render('params', 'onCourseEdit');
-					if (!$out) 
+					if (!$out)
 					{
 						continue;
 					}
 					?>
 					<fieldset class="adminform eventparams" id="params-<?php echo $plugin['name']; ?>">
-						<legend><?php echo JText::sprintf('%s Parameters', $plugin['title']); ?></legend>
+						<legend><?php echo JText::sprintf('COM_COURSES_FIELDSET_PARAMETERS', $plugin['title']); ?></legend>
 						<?php echo $out; ?>
 					</fieldset>
 					<?php
@@ -224,8 +207,8 @@ function submitbutton(pressbutton)
 		?>
 
 		<fieldset class="adminform">
-			<legend><span><?php echo JText::_('IMAGE'); ?></span></legend>
-			
+			<legend><span><?php echo JText::_('COM_COURSES_FIELDSET_IMAGE'); ?></span></legend>
+
 			<?php
 			if ($this->row->exists()) {
 				$logo = stripslashes($this->row->get('logo'));
@@ -235,15 +218,15 @@ function submitbutton(pressbutton)
 			<div style="padding-top: 2.5em">
 				<div id="ajax-uploader" data-action="index.php?option=<?php echo $this->option; ?>&amp;controller=logo&amp;task=upload&amp;type=course&amp;id=<?php echo $this->row->get('id'); ?>&amp;no_html=1&amp;<?php echo JUtility::getToken(); ?>=1">
 					<noscript>
-						<iframe width="100%" height="350" name="filer" id="filer" frameborder="0" src="index.php?option=<?php echo $this->option; ?>&amp;controller=logo&amp;tmpl=component&amp;file=<?php echo $file; ?>&amp;type=course&amp;id=<?php echo $this->row->get('id'); ?>"></iframe>
+						<iframe height="350" name="filer" id="filer" src="index.php?option=<?php echo $this->option; ?>&amp;controller=logo&amp;tmpl=component&amp;file=<?php echo $file; ?>&amp;type=course&amp;id=<?php echo $this->row->get('id'); ?>"></iframe>
 					</noscript>
 				</div>
 			</div>
-				<?php 
+				<?php
 				$width = 0;
 				$height = 0;
 				$this_size = 0;
-				if ($logo) 
+				if ($logo)
 				{
 					$path = DS . trim($this->config->get('uploadpath', '/site/courses'), DS) . DS . $this->row->get('id');
 
@@ -264,35 +247,33 @@ function submitbutton(pressbutton)
 				<table class="formed">
 					<tbody>
 						<tr>
-							<th><?php echo JText::_('File'); ?>:</th>
+							<th><?php echo JText::_('COM_COURSES_FILE'); ?>:</th>
 							<td>
-								<span id="img-name"><?php echo $this->row->get('logo', '[ none ]'); ?></span>
+								<span id="img-name"><?php echo $this->row->get('logo', JText::_('COM_COURSES_NONE')); ?></span>
 							</td>
 							<td>
-								<a id="img-delete" <?php echo $logo ? '' : 'style="display: none;"'; ?> href="index.php?option=<?php echo $this->option; ?>&amp;controller=logo&amp;tmpl=component&amp;task=remove&amp;currentfile=<?php echo $logo; ?>&amp;type=course&amp;id=<?php echo $this->row->get('id'); ?>&amp;<?php echo JUtility::getToken(); ?>=1" title="<?php echo JText::_('Delete'); ?>">[ x ]</a>
+								<a id="img-delete" <?php echo $logo ? '' : 'style="display: none;"'; ?> href="index.php?option=<?php echo $this->option; ?>&amp;controller=logo&amp;tmpl=component&amp;task=remove&amp;currentfile=<?php echo $logo; ?>&amp;type=course&amp;id=<?php echo $this->row->get('id'); ?>&amp;<?php echo JUtility::getToken(); ?>=1" title="<?php echo JText::_('COM_COURSES_DELETE'); ?>">[ x ]</a>
 							</td>
 						</tr>
 						<tr>
-							<th><?php echo JText::_('Size'); ?>:</th>
+							<th><?php echo JText::_('COM_COURSES_PICTURE_SIZE'); ?>:</th>
 							<td><span id="img-size"><?php echo \Hubzero\Utility\Number::formatBytes($this_size); ?></span></td>
 							<td></td>
 						</tr>
 						<tr>
-							<th><?php echo JText::_('Width'); ?>:</th>
+							<th><?php echo JText::_('COM_COURSES_PICTURE_WIDTH'); ?>:</th>
 							<td><span id="img-width"><?php echo $width; ?></span> px</td>
 							<td></td>
 						</tr>
 						<tr>
-							<th><?php echo JText::_('Height'); ?>:</th>
+							<th><?php echo JText::_('COM_COURSES_PICTURE_HEIGHT'); ?>:</th>
 							<td><span id="img-height"><?php echo $height; ?></span> px</td>
 							<td></td>
 						</tr>
 					</tbody>
 				</table>
 
-				<script type="text/javascript" src="/media/system/js/jquery.js"></script>
-				<script type="text/javascript" src="/media/system/js/jquery.noconflict.js"></script>
-				<script type="text/javascript" src="/media/system/js/jquery.fileuploader.js"></script>
+				<script type="text/javascript" src="../media/system/js/jquery.fileuploader.js"></script>
 				<script type="text/javascript">
 				String.prototype.nohtml = function () {
 					if (this.indexOf('?') == -1) {
@@ -301,9 +282,7 @@ function submitbutton(pressbutton)
 						return this + '&no_html=1';
 					}
 				};
-				jQuery(document).ready(function(jq){
-					var $ = jq;
-					
+				jQuery(document).ready(function($){
 					if ($("#ajax-uploader").length) {
 						var uploader = new qq.FileUploader({
 							element: $("#ajax-uploader")[0],
@@ -311,9 +290,9 @@ function submitbutton(pressbutton)
 							multiple: true,
 							debug: true,
 							template: '<div class="qq-uploader">' +
-										'<div class="qq-upload-button"><span>Click or drop file</span></div>' + 
-										'<div class="qq-upload-drop-area"><span>Click or drop file</span></div>' +
-										'<ul class="qq-upload-list"></ul>' + 
+										'<div class="qq-upload-button"><span><?php echo JText::_('COM_COURSES_UPLOAD_CLICK_OR_DROP'); ?></span></div>' +
+										'<div class="qq-upload-drop-area"><span><?php echo JText::_('COM_COURSES_UPLOAD_CLICK_OR_DROP'); ?></span></div>' +
+										'<ul class="qq-upload-list"></ul>' +
 									   '</div>',
 							onComplete: function(id, file, response) {
 								if (response.success) {
