@@ -36,249 +36,239 @@ defined('_JEXEC') or die('Restricted access');
  */
 class GroupsControllerMembership extends GroupsControllerAbstract
 {
-	/** 
+	/**
 	 * Override Execute Method
-	 * 
+	 *
 	 * @return 	void
 	 */
 	public function execute()
 	{
 		//get the cname
 		$this->cn = JRequest::getVar('cn', '');
-		
+
 		parent::execute();
 	}
-	
-	
+
+
 	/**
 	 *  Method to display invite box
-	 * 
-	 * @return     
+	 *
+	 * @return
 	 */
 	public function inviteTask()
 	{
 		// set the neeced layout
 		$this->view->setLayout('invite');
-		
+
 		// Check if they're logged in
-		if ($this->juser->get('guest')) 
+		if ($this->juser->get('guest'))
 		{
-			$this->loginTask('You must be logged to send invites to group members.');
+			$this->loginTask(JText::_('COM_GROUPS_INVITE_MUST_BE_LOGGED_IN'));
 			return;
 		}
-		
+
 		$this->_buildTitle();
 		$this->_buildPathway();
-		
+
 		//check to make sure we have  cname
-		if(!$this->cn)
+		if (!$this->cn)
 		{
 			$this->_errorHandler(400, JText::_('COM_GROUPS_ERROR_NO_ID'));
 		}
-		
+
 		// Load the group page
 		$this->view->group = \Hubzero\User\Group::getInstance( $this->cn );
-		
+
 		// Ensure we found the group info
-		if (!$this->view->group || !$this->view->group->get('gidNumber')) 
+		if (!$this->view->group || !$this->view->group->get('gidNumber'))
 		{
 			$this->_errorHandler( 404, JText::_('COM_GROUPS_ERROR_NOT_FOUND') );
 		}
-		
+
 		// Check authorization
-		if ($this->_authorize() != 'manager' && !$this->_authorizedForTask('group.invite')) 
+		if ($this->_authorize() != 'manager' && !$this->_authorizedForTask('group.invite'))
 		{
 			$this->_errorHandler( 403, JText::_('COM_GROUPS_ERROR_NOT_AUTH') );
 		}
-		
-		//determine params class based on joomla version
-		$paramsClass = 'JParameter';
-		if (version_compare(JVERSION, '1.6', 'ge'))
-		{
-			$paramsClass = 'JRegistry';
-		}
 
 		// Get group params
-		$gparams = new $paramsClass($this->view->group->get('params'));
-		if ($gparams->get('membership_control', 1) == 0) 
+		$gparams = new JRegistry($this->view->group->get('params'));
+		if ($gparams->get('membership_control', 1) == 0)
 		{
-			$this->setNotification('Group membership is not managed in the group interface.', 'error');
+			$this->setNotification(JText::_('COM_GROUPS_MEMBERSHIP_MANAGED_ELSEWHERE'), 'error');
 			$this->setRedirect( JRoute::_('index.php?option=com_groups&cn=' . $this->view->group->get('cn')) );
 			return;
 		}
-		
-		// push styles
-		$this->_getStyles();
-		
+
 		// get view notifications
 		$this->view->notifications = ($this->getNotifications()) ? $this->getNotifications() : array();
-		
+
 		//set some vars for view
 		$this->view->title = JText::_('Invite Members: ' . $this->view->group->get('description'));
 		$this->view->juser = $this->juser;
 		$this->view->msg = trim(JRequest::getVar('msg',''));
 		$this->view->return = trim(JRequest::getVar('return',''));
-		
+
 		//display view
 		$this->view->display();
 	}
-	
-	
+
+
 	/**
 	 *  Method to parse and send invites
-	 * 
-	 * @return     
+	 *
+	 * @return
 	 */
 	public function doinviteTask()
 	{
 		// Check if they're logged in
-		if ($this->juser->get('guest')) 
+		if ($this->juser->get('guest'))
 		{
-			$this->loginTask('You must be logged in to send invites to group members.');
+			$this->loginTask(JText::_('COM_GROUPS_INVITE_MUST_BE_LOGGED_IN'));
 			return;
 		}
-		
+
 		//check to make sure we have  cname
-		if(!$this->cn)
+		if (!$this->cn)
 		{
 			$this->_errorHandler(400, JText::_('COM_GROUPS_ERROR_NO_ID'));
 		}
-		
+
 		// Load the group page
 		$this->view->group = \Hubzero\User\Group::getInstance( $this->cn );
-		
+
 		// Ensure we found the group info
-		if (!$this->view->group || !$this->view->group->get('gidNumber')) 
+		if (!$this->view->group || !$this->view->group->get('gidNumber'))
 		{
 			$this->_errorHandler( 404, JText::_('COM_GROUPS_ERROR_NOT_FOUND') );
 		}
-		
+
 		// Check authorization
-		if ($this->_authorize() != 'manager' && !$this->_authorizedForTask('group.invite')) 
+		if ($this->_authorize() != 'manager' && !$this->_authorizedForTask('group.invite'))
 		{
 			$this->_errorHandler( 403, JText::_('COM_GROUPS_ERROR_NOT_AUTH') );
 		}
-		
+
 		//get request vars
 		$logins = trim(JRequest::getVar('logins',''));
 		$msg = trim(JRequest::getVar('msg',''));
-		
+
 		if (!$logins)
 		{
-			$this->setNotification('You must enter in names and/or email addresses to invite.', 'error');
+			$this->setNotification(JText::_('COM_GROUPS_INVITE_MUST_ENTER_DATA'), 'error');
 			$this->inviteTask();
 			return;
 		}
-		
+
 		// Get all the group's members
 		$members = $this->view->group->get('members');
 		$applicants = $this->view->group->get('applicants');
 		$current_invitees = $this->view->group->get('invitees');
-		
+
 		// Get invite emails
 		$group_inviteemails = new \Hubzero\User\Group\InviteEmail($this->database);
 		$current_inviteemails = $group_inviteemails->getInviteEmails($this->view->group->get('gidNumber'), true);
-		
+
 		//vars needed
 		$invitees = array();
 		$inviteemails = array();
 		$badentries = array();
 		$apps = array();
 		$mems = array();
-		
+
 		// Explode the string of logins/e-mails into an array
-		if (strstr($logins, ',')) 
+		if (strstr($logins, ','))
 		{
 			$la = explode(',', $logins);
 		}
-		else 
+		else
 		{
 			$la = array($logins);
 		}
 
-		foreach($la as $l)
+		foreach ($la as $l)
 		{
 			// Trim up content
 			$l = trim($l);
 
 			// If it was a user id
-			if (is_numeric($l)) 
+			if (is_numeric($l))
 			{
 				$user = JUser::getInstance($l);
 				$uid = $user->get('id');
 
 				// Ensure we found an account
-				if ($uid != '') 
+				if ($uid != '')
 				{
 					// If not a member
-					if (!in_array($uid, $members) && !in_array($uid, $current_invitees)) 
+					if (!in_array($uid, $members) && !in_array($uid, $current_invitees))
 					{
 						// If an applicant
 						// Make applicant a member
-						if (in_array($uid, $applicants)) 
+						if (in_array($uid, $applicants))
 						{
 							$apps[] = $uid;
 							$mems[] = $uid;
-						} 
-						else 
+						}
+						else
 						{
 							$invitees[] = $uid;
 						}
-					} 
-					else 
+					}
+					else
 					{
-						$badentries[] = array($uid, 'User is already a member or invited.');
+						$badentries[] = array($uid, JText::_('COM_GROUPS_INVITE_USER_IS_ALREADY_MEMBER'));
 					}
 				}
-			} 
-			else 
+			}
+			else
 			{
 				// If not a userid check if proper email
-				if (preg_match("/^[_\.\%0-9a-zA-Z-]+@([0-9a-zA-Z-]+\.)+[a-zA-Z]{2,6}$/i", $l)) 
+				if (preg_match("/^[_\.\%0-9a-zA-Z-]+@([0-9a-zA-Z-]+\.)+[a-zA-Z]{2,6}$/i", $l))
 				{
 					// Try to find an account that might match this e-mail
 					$this->database->setQuery("SELECT u.id FROM #__users AS u WHERE u.email='" . $l . "' OR u.email LIKE '" . $l . "\'%' LIMIT 1;");
 					$uid = $this->database->loadResult();
-					if (!$this->database->query()) 
+					if (!$this->database->query())
 					{
 						$this->setNotification($this->database->getErrorMsg(), 'error');
 					}
 
 					// If we found an ID, add it to the invitees list
-					if ($uid) 
+					if ($uid)
 					{
 						// Check if user is already member or invitee
 						// Check if applicant remove from applicants and add as member
 						// Check if in current email invitee if not add a new email invite
-						if (in_array($uid, $members) || in_array($uid, $current_invitees)) 
+						if (in_array($uid, $members) || in_array($uid, $current_invitees))
 						{
-							$badentries[] = array($uid, 'User is already a member or invitee.');
-						} 
-						elseif (in_array($uid, $applicants)) 
+							$badentries[] = array($uid, JText::_('COM_GROUPS_INVITE_USER_IS_ALREADY_MEMBER'));
+						}
+						elseif (in_array($uid, $applicants))
 						{
 							$apps[] = $uid;
 							$mems[] = $uid;
-						} 
-						else 
+						}
+						else
 						{
 							$invitees[] = $uid;
 						}
-					} 
-					else 
+					}
+					else
 					{
-						if (!in_array($l, $current_inviteemails)) 
+						if (!in_array($l, $current_inviteemails))
 						{
 							$inviteemails[] = array('email' => $l, 'gidNumber' => $this->view->group->get('gidNumber'), 'token' => $this->_randomString(32));
-						} 
-						else 
+						}
+						else
 						{
-							$badentries[] = array($l, 'Email address has already been invited.');
+							$badentries[] = array($l, JText::_('COM_GROUPS_INVITE_EMAIL_ALREADY_INVITED'));
 						}
 					}
-				} 
-				else 
+				}
+				else
 				{
-					$badentries[] = array($l, 'Entry is not a valid email address or user.');
+					$badentries[] = array($l, JText::_('COM_GROUPS_INVITE_EMAIL_NOT_VALID'));
 				}
 			}
 		}
@@ -295,14 +285,14 @@ class GroupsControllerMembership extends GroupsControllerAbstract
 			$group_inviteemails = new \Hubzero\User\Group\InviteEmail($this->database);
 			$group_inviteemails->save($ie);
 		}
-		
+
 		// log invites
 		GroupsModelLog::log(array(
 			'gidNumber' => $this->view->group->get('gidNumber'),
 			'action'    => 'membership_invites_sent',
 			'comments'  => array_merge($invitees, $inviteemails)
 		));
-		
+
 		// Get and set some vars
 		$jconfig = JFactory::getConfig();
 
@@ -315,7 +305,7 @@ class GroupsControllerMembership extends GroupsControllerAbstract
 		$subject = JText::sprintf('COM_GROUPS_INVITE_EMAIL_SUBJECT', $this->view->group->get('cn'));
 
 		// Message body for HUB user
-		$eview = new JView(array('name' => 'emails', 'layout' => 'invite'));
+		$eview = new \Hubzero\Component\View(array('name' => 'emails', 'layout' => 'invite'));
 		$eview->option = $this->_option;
 		$eview->sitename = $jconfig->getValue('config.sitename');
 		$eview->juser = $this->juser;
@@ -323,7 +313,7 @@ class GroupsControllerMembership extends GroupsControllerAbstract
 		$eview->msg = $msg;
 		$html = $eview->loadTemplate();
 		$html = str_replace("\n", "\r\n", $html);
-		
+
 		// build array of group invites to send
 		$groupInvitees = array();
 		foreach ($invitees as $invitee)
@@ -339,7 +329,7 @@ class GroupsControllerMembership extends GroupsControllerAbstract
 		{
 			// create new message
 			$message = new \Hubzero\Mail\Message();
-		
+
 			// build message object and send
 			$message->setSubject($subject)
 					->addFrom($from['email'], $from['name'])
@@ -355,7 +345,7 @@ class GroupsControllerMembership extends GroupsControllerAbstract
 		foreach ($inviteemails as $mbr)
 		{
 			// Message body for HUB user
-			$eview2 = new JView(array('name' => 'emails', 'layout' => 'inviteemail'));
+			$eview2 = new \Hubzero\Component\View(array('name' => 'emails', 'layout' => 'inviteemail'));
 			$eview2->option = $this->_option;
 			$eview2->sitename = $jconfig->getValue('config.sitename');
 			$eview2->juser = $this->juser;
@@ -364,10 +354,10 @@ class GroupsControllerMembership extends GroupsControllerAbstract
 			$eview2->token = $mbr['token'];
 			$html = $eview2->loadTemplate();
 			$html = str_replace("\n", "\r\n", $html);
-			
+
 			// create new message
 			$message = new \Hubzero\Mail\Message();
-	
+
 			// build message object and send
 			$message->setSubject($subject)
 					->addFrom($from['email'], $from['name'])
@@ -386,41 +376,41 @@ class GroupsControllerMembership extends GroupsControllerAbstract
 		$success_message = '';
 		$error_message = '';
 
-		if (count($all_invites) > 0) 
+		if (count($all_invites) > 0)
 		{
-			$success_message = 'Group invites were successfully sent to the following users/email addresses: <br />';
+			$success_message = JText::_('COM_GROUPS_INVITE_SUCCESS_MESSAGE');
 			foreach ($all_invites as $invite)
 			{
-				if (is_numeric($invite)) 
+				if (is_numeric($invite))
 				{
 					$user = JUser::getInstance($invite);
 					$success_message .= ' - ' . $user->get('name') . '<br />';
-				} 
-				else 
+				}
+				else
 				{
 					$success_message .= ' - ' . $invite['email'] . '<br />';
 				}
 			}
 		}
 
-		if (count($badentries) > 0) 
+		if (count($badentries) > 0)
 		{
-			$error_message = 'We were unable to send invites to the following entries: <br />';
+			$error_message = JText::_('COM_GROUPS_INVITE_ERROR_MESSAGE');
 			foreach ($badentries as $entry)
 			{
-				if (is_numeric($entry[0])) 
+				if (is_numeric($entry[0]))
 				{
 					$user = JUser::getInstance($entry[0]);
-					if ($user->get('name') != '') 
+					if ($user->get('name') != '')
 					{
 						$error_message .= ' - ' . $user->get('name') . ' &rarr; ' . $entry[1] . '<br />';
-					} 
-					else 
+					}
+					else
 					{
 						$error_message .= ' - ' . $entry[0] . ' &rarr; ' . $entry[1] . '<br />';
 					}
-				} 
-				else 
+				}
+				else
 				{
 					$error_message .= ' - ' . $entry[0] . ' &rarr; ' . $entry[1] . '<br />';
 				}
@@ -434,87 +424,80 @@ class GroupsControllerMembership extends GroupsControllerAbstract
 		// Redirect back to view group
 		$this->setRedirect( JRoute::_('index.php?option=' . $this->_option . '&cn=' . $this->view->group->get('cn')) );
 	}
-	
-	
+
+
 	/**
 	 *  Accept Group Invite Method
-	 * 
-	 * @return     
+	 *
+	 * @return
 	 */
 	public function acceptTask()
 	{
 		//get invite token
 		$token = JRequest::getVar('token','','get');
-		
+
 		// Check if they're logged in
-		if ($this->juser->get('guest')) 
+		if ($this->juser->get('guest'))
 		{
 			$link = null;
-			if($token)
+			if ($token)
 			{
 				$link = JRoute::_('index.php?option=com_groups&cn='.$this->cn.'&task=accept&token='.$token);
 			}
-			
-			$this->loginTask('You must be logged in to accept a group invite.', $link);
+
+			$this->loginTask(JText::_('COM_GROUPS_INVITE_MUST_BE_LOGGED_IN_TO_ACCEPT'), $link);
 			return;
 		}
-		
+
 		//check to make sure we have  cname
-		if(!$this->cn)
+		if (!$this->cn)
 		{
 			$this->_errorHandler(400, JText::_('COM_GROUPS_ERROR_NO_ID'));
 		}
-		
+
 		// Load the group page
 		$this->view->group = \Hubzero\User\Group::getInstance( $this->cn );
-		
+
 		// Ensure we found the group info
-		if (!$this->view->group || !$this->view->group->get('gidNumber')) 
+		if (!$this->view->group || !$this->view->group->get('gidNumber'))
 		{
 			$this->_errorHandler( 404, JText::_('COM_GROUPS_ERROR_NOT_FOUND') );
 		}
-		
+
 		//do we have permission to join group
-		if ($this->view->group->get('type') == 2) 
+		if ($this->view->group->get('type') == 2)
 		{
 			$this->_errorHandler( 403, JText::_('COM_GROUPS_ERROR_FORBIDDEN') );
 			return;
 		}
-		
-		//determine params class based on joomla version
-		$paramsClass = 'JParameter';
-		if (version_compare(JVERSION, '1.6', 'ge'))
-		{
-			$paramsClass = 'JRegistry';
-		}
 
 		// Get the group params
-		$gparams = new $paramsClass($this->view->group->get('params'));
+		$gparams = new JRegistry($this->view->group->get('params'));
 
 		// If membership is managed in seperate place disallow action
-		if ($gparams->get('membership_control', 1) == 0) 
+		if ($gparams->get('membership_control', 1) == 0)
 		{
-			$this->setNotification('Group membership is not managed in the group interface.', 'error');
+			$this->setNotification(JText::_('COM_GROUPS_MEMBERSHIP_MANAGED_ELSEWHERE'), 'error');
 			$this->setRedirect( JRoute::_('index.php?option=com_groups&cn=' . $this->view->group->get('cn')) );
 			return;
 		}
-		
+
 		//get current members and invitees
 		$members = $this->view->group->get("members");
 		$invitees = $this->view->group->get('invitees');
-		
+
 		// Get invite emails
 		$group_inviteemails = new \Hubzero\User\Group\InviteEmail($this->database);
 		$inviteemails = $group_inviteemails->getInviteEmails($this->view->group->get('gidNumber'), true);
 		$inviteemails_with_token = $group_inviteemails->getInviteEmails($this->view->group->get('gidNumber'), false);
-		
+
 		//are we already a member
-		if (in_array($this->juser->get('id'), $members)) 
+		if (in_array($this->juser->get('id'), $members))
 		{
 			$this->setRedirect(JRoute::_('index.php?option=com_groups&cn=' . $this->view->group->get("cn")));
 			return;
 		}
-		
+
 		//get request vars
 		$return = strtolower(trim(JRequest::getVar('return', '', 'get')));
 
@@ -525,11 +508,11 @@ class GroupsControllerMembership extends GroupsControllerAbstract
 			$this->database->setQuery($sql);
 			$invite = $this->database->loadAssoc();
 
-			if ($invite) 
+			if ($invite)
 			{
 				$this->view->group->add('members',array($this->juser->get('id')));
 				$this->view->group->update();
-				
+
 				$sql = "DELETE FROM #__xgroups_inviteemails WHERE id=" . $this->database->quote($invite['id']);
 				$this->database->setQuery($sql);
 				$this->database->query();
@@ -553,14 +536,14 @@ class GroupsControllerMembership extends GroupsControllerAbstract
 		{
 			$this->_errorHandler(404, JText::_('COM_GROUPS_ERROR_UNABLE_TO_JOIN'));
 		}
-		
+
 		// log invites
 		GroupsModelLog::log(array(
 			'gidNumber' => $this->view->group->get('gidNumber'),
 			'action'    => 'membership_invite_accepted',
 			'comments'  => array($this->juser->get('id'))
 		));
-		
+
 		//get site config
 		$jconfig = JFactory::getConfig();
 
@@ -568,14 +551,14 @@ class GroupsControllerMembership extends GroupsControllerAbstract
 		$subject = JText::sprintf('COM_GROUPS_EMAIL_MEMBERSHIP_ACCEPTED_SUBJECT', $this->view->group->get('cn'));
 
 		// Build the e-mail message
-		$eview = new JView(array('name' => 'emails', 'layout' => 'accepted'));
+		$eview = new \Hubzero\Component\View(array('name' => 'emails', 'layout' => 'accepted'));
 		$eview->option = $this->_option;
 		$eview->sitename = $jconfig->getValue('config.sitename');
 		$eview->juser = $this->juser;
 		$eview->group = $this->view->group;
 		$body = $eview->loadTemplate();
 		$body = str_replace("\n", "\r\n", $body);
-		
+
 		// Build the "from" portion of the e-mail
 		$from = array();
 		$from['name']  = $jconfig->getValue('config.sitename') . ' ' . JText::_(strtoupper($this->_name));
@@ -583,7 +566,7 @@ class GroupsControllerMembership extends GroupsControllerAbstract
 
 		// Get the system administrator e-mail
 		$emailadmin = $jconfig->getValue('config.mailfrom');
-		
+
 		// build array of managers
 		$managers = array();
 		foreach ($this->view->group->get('managers') as $m)
@@ -594,10 +577,10 @@ class GroupsControllerMembership extends GroupsControllerAbstract
 				$managers[$profile->get('email')] = $profile->get('name');
 			}
 		}
-		
+
 		// create new message
 		$message = new \Hubzero\Mail\Message();
-	
+
 		// build message object and send
 		$message->setSubject($subject)
 				->addFrom($from['email'], $from['name'])
@@ -607,81 +590,78 @@ class GroupsControllerMembership extends GroupsControllerAbstract
 				->addHeader('X-Component-Object', 'group_invite_accepted')
 				->addPart($body, 'text/plain')
 				->send();
-		
+
 		//set notification fro user
-		$this->setNotification('You have successfully accepted your group invite.', 'passed');
-		
+		$this->setNotification(JText::_('COM_GROUPS_INVITE_ACCEPTED_SUCCESS'), 'passed');
+
 		// Action Complete. Redirect to appropriate page
-		if ($return == 'browse') 
+		if ($return == 'browse')
 		{
 			$this->setRedirect( JRoute::_('index.php?option=' . $this->_option) );
-		} 
-		else 
+		}
+		else
 		{
 			$this->setRedirect( JRoute::_('index.php?option=' . $this->_option . '&cn='. $this->view->group->get('cn')) );
 		}
 	}
-	
+
 	/**
 	 *  Cancel Membership Task
-	 * 
-	 * @return     
+	 *
+	 * @return
 	 */
 	public function cancelTask()
 	{
 		// Check if they're logged in
-		if ($this->juser->get('guest')) 
+		if ($this->juser->get('guest'))
 		{
-			$this->loginTask('You must be logged in to cancel group memberships.');
+			$this->loginTask(JText::_('COM_GROUPS_INVITE_MUST_BE_LOGGED_IN_TO_CANCEL'));
 			return;
 		}
-		
+
 		//check to make sure we have  cname
-		if(!$this->cn)
+		if (!$this->cn)
 		{
 			$this->_errorHandler(400, JText::_('COM_GROUPS_ERROR_NO_ID'));
 		}
-		
+
 		// Load the group page
 		$this->view->group = Hubzero\User\Group::getInstance( $this->cn );
-		
+
 		// Ensure we found the group info
-		if (!$this->view->group || !$this->view->group->get('gidNumber')) 
+		if (!$this->view->group || !$this->view->group->get('gidNumber'))
 		{
 			$this->_errorHandler( 404, JText::_('COM_GROUPS_ERROR_NOT_FOUND') );
 		}
-		
-		//determine params class based on joomla version
-		$paramsClass = 'JParameter';
-		if (version_compare(JVERSION, '1.6', 'ge'))
-		{
-			$paramsClass = 'JRegistry';
-		}
 
 		// Get the group params
-		$gparams = new $paramsClass($this->view->group->get('params'));
+		$gparams = new JRegistry($this->view->group->get('params'));
 
 		// If membership is managed in seperate place disallow action
-		if ($gparams->get('membership_control', 1) == 0) 
+		if ($gparams->get('membership_control', 1) == 0)
 		{
-			$this->setNotification('Group membership is not managed in the group interface.', 'error');
+			$this->setNotification(JText::_('COM_GROUPS_MEMBERSHIP_MANAGED_ELSEWHERE'), 'error');
 			$this->setRedirect( JRoute::_('index.php?option=com_groups&cn=' . $this->view->group->get('cn')) );
 			return;
 		}
-		
+
 		//get request vars
 		$return = strtolower(trim(JRequest::getVar('return', '', 'get')));
-		
+
 		// Remove the user from the group
 		$this->view->group->remove('managers', $this->juser->get('id'));
 		$this->view->group->remove('members', $this->juser->get('id'));
 		$this->view->group->remove('applicants', $this->juser->get('id'));
 		$this->view->group->remove('invitees', $this->juser->get('id'));
-		if ($this->view->group->update() === false) 
+		if ($this->view->group->update() === false)
 		{
 			$this->setNotification(JText::_('GROUPS_ERROR_CANCEL_MEMBERSHIP_FAILED'), 'error');
 		}
 
+		// delete member roles
+		require_once JPATH_ROOT . DS . 'plugins' . DS . 'groups' . DS . 'members' . DS . 'role.php';
+		GroupsMembersRole::deleteRolesForUserWithId($this->juser->get('id'));
+
 		// Log the membership cancellation
 		GroupsModelLog::log(array(
 			'gidNumber' => $this->view->group->get('gidNumber'),
@@ -700,7 +680,7 @@ class GroupsControllerMembership extends GroupsControllerAbstract
 		$subject = JText::sprintf('COM_GROUPS_EMAIL_MEMBERSHIP_CANCELLED_SUBJECT', $this->view->group->get('cn'));
 
 		// Build the e-mail message
-		$eview = new JView(array('name' => 'emails', 'layout' => 'cancelled'));
+		$eview = new \Hubzero\Component\View(array('name' => 'emails', 'layout' => 'cancelled'));
 		$eview->option = $this->_option;
 		$eview->sitename = $jconfig->getValue('config.sitename');
 		$eview->juser = $this->juser;
@@ -723,98 +703,91 @@ class GroupsControllerMembership extends GroupsControllerAbstract
 		{
 			$this->setError(JText::_('GROUPS_ERROR_EMAIL_MANAGERS_FAILED') . ' ' . $emailadmin);
 		}
-		
+
 		// Action Complete. Redirect to appropriate page
 		$this->setRedirect(
 			JRoute::_('index.php?option=com_members&id=' . $this->juser->get('id') . '&active=groups'),
-			'You have successfully canceled your group membership.',
+			JText::_('COM_GROUPS_INVITE_CANCEL_SUCCESS'),
 			'passed'
 		);
 	}
 
-	
+
 	/**
 	 *  Join Group Method
-	 * 
-	 * @return     
+	 *
+	 * @return
 	 */
 	public function joinTask()
 	{
 		// Check if they're logged in
-		if ($this->juser->get('guest')) 
+		if ($this->juser->get('guest'))
 		{
-			$this->loginTask('You must be logged in to join a group.');
+			$this->loginTask(JText::_('COM_GROUPS_INVITE_MUST_BE_LOGGED_IN_TO_JOIN'));
 			return;
 		}
-		
+
 		//check to make sure we have  cname
-		if(!$this->cn)
+		if (!$this->cn)
 		{
 			$this->_errorHandler(400, JText::_('COM_GROUPS_ERROR_NO_ID'));
 		}
-		
+
 		// Load the group page
 		$this->view->group = \Hubzero\User\Group::getInstance( $this->cn );
-		
+
 		// Ensure we found the group info
-		if (!$this->view->group || !$this->view->group->get('gidNumber')) 
+		if (!$this->view->group || !$this->view->group->get('gidNumber'))
 		{
 			$this->_errorHandler( 404, JText::_('COM_GROUPS_ERROR_NOT_FOUND') );
 		}
-		
-		//determine params class based on joomla version
-		$paramsClass = 'JParameter';
-		if (version_compare(JVERSION, '1.6', 'ge'))
-		{
-			$paramsClass = 'JRegistry';
-		}
 
 		// Get the group params
-		$gparams = new $paramsClass($this->view->group->get('params'));
+		$gparams = new JRegistry($this->view->group->get('params'));
 
 		// If membership is managed in seperate place disallow action
-		if ($gparams->get('membership_control', 1) == 0) 
+		if ($gparams->get('membership_control', 1) == 0)
 		{
-			$this->setNotification('Group membership is not managed in the group interface.', 'error');
+			$this->setNotification(JText::_('COM_GROUPS_MEMBERSHIP_MANAGED_ELSEWHERE'), 'error');
 			$this->setRedirect( JRoute::_('index.php?option=com_groups&cn=' . $this->view->group->get('cn')) );
 			return;
 		}
-		
+
 		//get groups managers, members, applicants, and invtees
 		$members = $this->view->group->get('members');
 		$applicants = $this->view->group->get('applicants');
 		$invitees = $this->view->group->get('invitees');
-		
+
 		//check if already member, or applicant
 		if (in_array($this->juser->get('id'), $members))
 		{
 			$this->setRedirect( JRoute::_('index.php?option=com_groups&cn='.$this->view->group->get('cn')) );
 			return;
 		}
-		
-		//check if applicant
+
+		// check if applicant
 		if (in_array($this->juser->get('id'), $applicants))
 		{
-			$this->setNotification('You are already awaiting approval to join this group.', 'info');
+			$this->setNotification(JText::_('COM_GROUPS_INVITE_ALREADY_APPLIED'), 'info');
 			$this->setRedirect( JRoute::_('index.php?option=com_groups&cn='.$this->view->group->get('cn')) );
 			return;
 		}
-		
+
 		//is the group closed or invite only
 		if ($this->view->group->get('join_policy') == 3 || $this->view->group->get('join_policy') == 2)
 		{
-			$this->setNotification('You are unable to join the group at this time due to the join policy set by the group managers.', 'warning');
+			$this->setNotification(JText::_('COM_GROUPS_INVITE_UNABLE_TO_JOIN'), 'warning');
 			$this->setRedirect( JRoute::_('index.php?option=com_groups&cn='.$this->view->group->get('cn')) );
 			return;
 		}
-		
+
 		//is the group restricted
 		if ($this->view->group->get('join_policy') == 1)
 		{
 			$this->requestTask();
 			return;
 		}
-		
+
 		//if this group is open just make a member
 		if ($this->view->group->get('join_policy') == 0)
 		{
@@ -822,98 +795,91 @@ class GroupsControllerMembership extends GroupsControllerAbstract
 			$this->view->group->remove('applicants', array($this->juser->get('id')));
 			$this->view->group->remove('invitees', array($this->juser->get('id')));
 			$this->view->group->update();
-			
+
 			// Log the membership approval
 			GroupsModelLog::log(array(
 				'gidNumber' => $this->view->group->get('gidNumber'),
 				'action'    => 'membership_approved',
 				'comments'  => array($this->juser->get('id'))
 			));
-			
+
 			$this->setRedirect( JRoute::_('index.php?option=com_groups&cn='.$this->view->group->get('cn')) );
 			return;
 		}
 	}
-	
-	
+
+
 	/**
 	 * Show request membership form
-	 * 
+	 *
 	 * @return     array
 	 */
 	public function requestTask()
 	{
 		//set the layout
 		$this->view->setLayout('request');
-		
+
 		// get view notifications
 		$this->view->notifications = ($this->getNotifications()) ? $this->getNotifications() : array();
-		
+
 		//set title
-		$this->view->title = "Request Group Membership: " . $this->view->group->get('description');
-		
+		$this->view->title = JText::_('COM_GROUPS_INVITE_REQUEST') . ": " . $this->view->group->get('description');
+
 		//display
 		$this->view->display();
 	}
-	
-	
+
+
 	/**
 	 * Add membership request for user
-	 * 
+	 *
 	 * @return     array
 	 */
 	public function dorequestTask()
 	{
 		// Check if they're logged in
-		if ($this->juser->get('guest')) 
+		if ($this->juser->get('guest'))
 		{
-			$this->loginTask('You must be logged in to request access a group.');
+			$this->loginTask(JText::_('COM_GROUPS_INVITE_MUST_BE_LOGGED_IN_TO_REQUEST'));
 			return;
 		}
-		
+
 		//check to make sure we have  cname
-		if(!$this->cn)
+		if (!$this->cn)
 		{
 			$this->_errorHandler(400, JText::_('COM_GROUPS_ERROR_NO_ID'));
 		}
-		
+
 		// Load the group page
 		$this->view->group = \Hubzero\User\Group::getInstance( $this->cn );
-		
+
 		// Ensure we found the group info
-		if (!$this->view->group || !$this->view->group->get('gidNumber')) 
+		if (!$this->view->group || !$this->view->group->get('gidNumber'))
 		{
 			$this->_errorHandler( 404, JText::_('COM_GROUPS_ERROR_NOT_FOUND') );
 		}
-		
-		//determine params class based on joomla version
-		$paramsClass = 'JParameter';
-		if (version_compare(JVERSION, '1.6', 'ge'))
-		{
-			$paramsClass = 'JRegistry';
-		}
 
 		// Get the group params
-		$gparams = new $paramsClass($this->view->group->get('params'));
+		$gparams = new JRegistry($this->view->group->get('params'));
 
 		// If membership is managed in seperate place disallow action
-		if ($gparams->get('membership_control', 1) == 0) 
+		if ($gparams->get('membership_control', 1) == 0)
 		{
-			$this->setNotification('Group membership is not managed in the group interface.', 'error');
+			$this->setNotification(JText::_('COM_GROUPS_MEMBERSHIP_MANAGED_ELSEWHERE'), 'error');
 			$this->setRedirect( JRoute::_('index.php?option=com_groups&cn=' . $this->view->group->get('cn')) );
 			return;
 		}
-		
+
 		//make sure group has restricted policy
 		if ($this->view->group->get('join_policy') != 1)
 		{
 			return;
 		}
-		
+
 		//add user to applicants
 		$this->view->group->add('applicants', array($this->juser->get('id')));
 		$this->view->group->update();
-		
+
 		// Instantiate the reason object and bind the incoming data
 		$row = new GroupsReason($this->database);
 		$row->uidNumber = $this->juser->get('id');
@@ -923,24 +889,24 @@ class GroupsControllerMembership extends GroupsControllerAbstract
 		$row->date      = JFactory::getDate()->toSql();
 
 		// Check and store the reason
-		if (!$row->check()) 
+		if (!$row->check())
 		{
 			JError::raiseError(500, $row->getError());
 			return;
 		}
-		if (!$row->store()) 
+		if (!$row->store())
 		{
 			JError::raiseError(500, $row->getError());
 			return;
 		}
-		
+
 		// Log the membership request
 		GroupsModelLog::log(array(
 			'gidNumber' => $this->view->group->get('gidNumber'),
 			'action'    => 'membership_requested',
 			'comments'  => array($this->juser->get('id'))
 		));
-		
+
 		//get site config
 		$jconfig = JFactory::getConfig();
 
@@ -948,7 +914,7 @@ class GroupsControllerMembership extends GroupsControllerAbstract
 		$subject = JText::sprintf('COM_GROUPS_JOIN_REQUEST_EMAIL_SUBJECT', $this->view->group->get('cn'));
 
 		// Build the e-mail message
-		$eview = new JView(array('name' => 'emails', 'layout' => 'request'));
+		$eview = new \Hubzero\Component\View(array('name' => 'emails', 'layout' => 'request'));
 		$eview->option = $this->_option;
 		$eview->sitename = $jconfig->getValue('config.sitename');
 		$eview->juser = $this->juser;
@@ -964,7 +930,7 @@ class GroupsControllerMembership extends GroupsControllerAbstract
 		$from = array();
 		$from['name']  = $jconfig->getValue('config.sitename') . ' ' . JText::_(strtoupper($this->_name));
 		$from['email'] = $jconfig->getValue('config.mailfrom');
-		
+
 		// build array of managers
 		$managers = array();
 		foreach ($this->view->group->get('managers') as $m)
@@ -975,10 +941,10 @@ class GroupsControllerMembership extends GroupsControllerAbstract
 				$managers[$profile->get('email')] = $profile->get('name');
 			}
 		}
-		
+
 		// create new message
 		$message = new \Hubzero\Mail\Message();
-	
+
 		// build message object and send
 		$message->setSubject($subject)
 				->addFrom($from['email'], $from['name'])
@@ -988,18 +954,18 @@ class GroupsControllerMembership extends GroupsControllerAbstract
 				->addHeader('X-Component-Object', 'group_membership_requested')
 				->addPart($html, 'text/plain')
 				->send();
-		
+
 		//tell the user they just did good
-		$this->setNotification('Your membership request has been forwarded to the group managers for approval.', 'passed');
-		
+		$this->setNotification(JText::_('COM_GROUPS_INVITE_REQUEST_FORWARDED'), 'passed');
+
 		// Push through to the groups listing
 		$this->setRedirect( JRoute::_('index.php?option=' . $this->_option . '&cn=' . $this->view->group->get('cn')) );
 	}
-	
-	
+
+
 	/**
 	 *  Creates Random Token String
-	 * 
+	 *
 	 * @param 	int	$strLength		Length of string desired
 	 * @return 	String				Random string
 	 */
