@@ -38,26 +38,26 @@ class WikiControllerComments extends \Hubzero\Component\SiteController
 {
 	/**
 	 * Constructor
-	 * 
+	 *
 	 * @param      array $config Optional configurations
 	 * @return     void
 	 */
 	public function __construct($config=array())
 	{
 		$this->_base_path = JPATH_ROOT . DS . 'components' . DS . 'com_wiki';
-		if (isset($config['base_path'])) 
+		if (isset($config['base_path']))
 		{
 			$this->_base_path = $config['base_path'];
 		}
 
 		$this->_sub = false;
-		if (isset($config['sub'])) 
+		if (isset($config['sub']))
 		{
 			$this->_sub = $config['sub'];
 		}
 
 		$this->_group = false;
-		if (isset($config['group'])) 
+		if (isset($config['group']))
 		{
 			$this->_group = $config['group'];
 		}
@@ -74,19 +74,14 @@ class WikiControllerComments extends \Hubzero\Component\SiteController
 
 	/**
 	 * Execute a task
-	 * 
+	 *
 	 * @return     void
 	 */
 	public function execute()
 	{
-		/*if ($this->_sub || $this->_option != 'com_wiki')
-		{
-			$this->config = JComponentHelper::getParams('com_wiki');
-		}*/
-
 		if (!$this->book->pages('count'))
 		{
-			if ($result = $this->book->scribe($this->_option)) 
+			if ($result = $this->book->scribe($this->_option))
 			{
 				$this->setError($result);
 			}
@@ -115,7 +110,7 @@ class WikiControllerComments extends \Hubzero\Component\SiteController
 
 	/**
 	 * Display comments for a wiki page
-	 * 
+	 *
 	 * @return     void
 	 */
 	public function displayTask()
@@ -143,24 +138,17 @@ class WikiControllerComments extends \Hubzero\Component\SiteController
 			$this->view->mycomment->set('created_by', $this->juser->get('id'));
 		}
 
-		if (!$this->_sub)
-		{
-			// Include any CSS
-			$this->_getStyles();
-			$this->_getScripts('assets/js/wiki', 'com_wiki');
-		}
-
-		// Prep the pagename for display 
+		// Prep the pagename for display
 		// e.g. "MainPage" becomes "Main Page"
 		$this->view->title = $this->page->get('title');
 
 		// Set the page's <title> tag
 		$document = JFactory::getDocument();
-		$document->setTitle(JText::_(strtoupper($this->_name)) . ': ' . $this->view->title . ': ' . JText::_(strtoupper($this->_task)));
+		$document->setTitle(JText::_(strtoupper($this->_option)) . ': ' . $this->view->title . ': ' . JText::_(strtoupper($this->_option . '_' . $this->_task)));
 
 		// Set the pathway
 		$pathway = JFactory::getApplication()->getPathway();
-		if (count($pathway->getPathWay()) <= 0) 
+		if (count($pathway->getPathWay()) <= 0)
 		{
 			$pathway->addItem(
 				JText::_(strtoupper($this->_name)),
@@ -180,7 +168,7 @@ class WikiControllerComments extends \Hubzero\Component\SiteController
 		$this->view->juser = $this->juser;
 		$this->view->message = $this->_message;
 
-		if ($this->getError()) 
+		if ($this->getError())
 		{
 			foreach ($this->getErrors() as $error)
 			{
@@ -193,7 +181,7 @@ class WikiControllerComments extends \Hubzero\Component\SiteController
 
 	/**
 	 * Create a comment
-	 * 
+	 *
 	 * @return     void
 	 */
 	public function newTask()
@@ -203,18 +191,18 @@ class WikiControllerComments extends \Hubzero\Component\SiteController
 
 	/**
 	 * Edit a comment
-	 * 
+	 *
 	 * @return     void
 	 */
 	public function editTask()
 	{
 		// Is the user logged in?
 		// If not, then we need to stop everything else and display a login form
-		if ($this->juser->get('guest')) 
+		if ($this->juser->get('guest'))
 		{
 			$url = JRequest::getVar('REQUEST_URI', '', 'server');
 			$this->setRedirect(
-				JRoute::_('index.php?option=com_login&return=' . base64_encode($url))
+				JRoute::_('index.php?option=com_users&view=login&return=' . base64_encode($url))
 			);
 			return;
 		}
@@ -226,7 +214,7 @@ class WikiControllerComments extends \Hubzero\Component\SiteController
 		// This is how comments() knows if it needs to display a form or not
 		$this->view->mycomment = new WikiModelComment($id);
 
-		if (!$id) 
+		if (!$id)
 		{
 			// No ID, so we're creating a new comment
 			// In that case, we'll need to set some data...
@@ -243,7 +231,7 @@ class WikiControllerComments extends \Hubzero\Component\SiteController
 
 	/**
 	 * Save a comment
-	 * 
+	 *
 	 * @return     void
 	 */
 	public function saveTask()
@@ -254,33 +242,33 @@ class WikiControllerComments extends \Hubzero\Component\SiteController
 		$fields = JRequest::getVar('comment', array(), 'post');
 
 		// Bind the form data to our object
-		$this->view->mycomment = new WikiModelComment($fields['id']);
-		if (!$this->view->mycomment->bind($fields)) 
+		$comment = new WikiModelComment($fields['id']);
+		if (!$comment->bind($fields))
 		{
-			$this->setError($this->view->mycomment->getError());
+			$this->setError($comment->getError());
 			$this->displayTask();
 			return;
 		}
 
 		// Parse the wikitext and set some values
-		$this->view->mycomment->set('chtml', $this->view->mycomment->content('parsed'));
-		$this->view->mycomment->set('anonymous', ($this->view->mycomment->get('anonymous') ? 1 : 0));
-		$this->view->mycomment->set('created', ($this->view->mycomment->get('created') ? $this->view->mycomment->get('created') : date("Y-m-d H:i:s")));
+		$comment->set('chtml', $comment->content('parsed'));
+		$comment->set('anonymous', ($comment->get('anonymous') ? 1 : 0));
+		$comment->set('created', ($comment->get('created') ? $comment->get('created') : JFactory::getDate()->toSql()));
 
 		// Save the data
-		if (!$this->view->mycomment->store(true)) 
+		if (!$comment->store(true))
 		{
-			$this->setError($this->view->mycomment->getError());
+			$this->setError($comment->getError());
 			$this->displayTask();
 			return;
 		}
 
-		// Did they rate the page? 
+		// Did they rate the page?
 		// If so, update the page with the new average rating
-		if ($this->view->mycomment->get('rating')) 
+		if ($comment->get('rating'))
 		{
 			$this->page->calculateRating();
-			if (!$this->page->store()) 
+			if (!$this->page->store())
 			{
 				$this->setError($this->page->getError());
 			}
@@ -294,7 +282,7 @@ class WikiControllerComments extends \Hubzero\Component\SiteController
 
 	/**
 	 * Remove a comment
-	 * 
+	 *
 	 * @return     void
 	 */
 	public function removeTask()
@@ -303,19 +291,19 @@ class WikiControllerComments extends \Hubzero\Component\SiteController
 		$cls = 'message';
 
 		// Make sure we have a comment to delete
-		if (($id = JRequest::getInt('id', 0))) 
+		if (($id = JRequest::getInt('id', 0)))
 		{
 			// Make sure they're authorized to delete (must be an author)
-			if ($this->page->access('delete', 'comment')) 
+			if ($this->page->access('delete', 'comment'))
 			{
 				$comment = new WikiModelComment($id);
 				$comment->set('status', 2);
-				if ($comment->store())
+				if ($comment->store(false))
 				{
 					$msg = JText::_('COM_WIKI_COMMENT_DELETED');
 				}
-			} 
-			else 
+			}
+			else
 			{
 				$msg = JText::_('COM_WIKI_ERROR_NOTAUTH');
 				$cls = 'error';
@@ -329,24 +317,5 @@ class WikiControllerComments extends \Hubzero\Component\SiteController
 			$cls
 		);
 	}
-
-	/**
-	 * Flag a comment as abusive
-	 * 
-	 * @return     void
-	 */
-	public function reportTask()
-	{
-		// Make sure we have a comment to report
-		if (($id = JRequest::getInt('id', 0, 'request'))) 
-		{
-			$comment = new WikiModelComment($id);
-			$comment->report();
-
-			$this->addComponentMessage(JText::sprintf('WIKI_COMMENT_REPORTED', $id));
-		}
-
-		$this->displayTask();
-	}
 }
 
