@@ -82,7 +82,7 @@ class View extends Object
 	 * @var array
 	 */
 	protected $_path = array(
-		'template' => array(), 
+		'template' => array(),
 		'helper'   => array()
 	);
 
@@ -229,11 +229,11 @@ class View extends Object
 	 * an object, an associative array, or a single value by name.
 	 *
 	 * You are not allowed to set variables that begin with an underscore;
-	 * these are either private properties for JView or private variables
+	 * these are either private properties for View or private variables
 	 * within the template script itself.
 	 *
 	 * <code>
-	 * $view = new JView;
+	 * $view = new View;
 	 *
 	 * // Assign directly
 	 * $view->var1 = 'something';
@@ -560,7 +560,6 @@ class View extends Object
 		}
 		else
 		{
-			print_r($this->_path['template']); die();
 			throw new InvalidLayoutException(\JText::sprintf('JLIB_APPLICATION_ERROR_LAYOUTFILE_NOT_FOUND', $file), 500);
 		}
 	}
@@ -615,7 +614,7 @@ class View extends Object
 					$component = preg_replace('/[^A-Z0-9_\.-]/i', '', $component);
 
 					$this->_addPath(
-						'template', 
+						'template',
 						JPATH_THEMES . '/' . $app->getTemplate() . '/html/' . $component . '/' . $this->getName()
 					);
 				}
@@ -686,9 +685,9 @@ class View extends Object
 	 */
 	public function setHelperManager($helpers)
 	{
-		if (is_string($helpers)) 
+		if (is_string($helpers))
 		{
-			if (!class_exists($helpers)) 
+			if (!class_exists($helpers))
 			{
 				throw new InvalidHelperManagerException(sprintf(
 					'Invalid helper manager class provided (%s)',
@@ -697,7 +696,7 @@ class View extends Object
 			}
 			$helpers = new $helpers();
 		}
-		if (!$helpers instanceof HelperManager) 
+		if (!$helpers instanceof HelperManager)
 		{
 			throw new InvalidHelperManagerException(sprintf(
 				'Helper manager must extend Hubzero\View\HelperManager; got type "%s" instead',
@@ -718,16 +717,16 @@ class View extends Object
 	 */
 	public function helpers($helpers=null)
 	{
-		if (null === $this->helpers) 
+		if (null === $this->helpers)
 		{
 			if (null === $helpers)
 			{
 				$helpers = new HelperManager();
 			}
 
-			if (is_string($helpers)) 
+			if (is_string($helpers))
 			{
-				if (!class_exists($helpers)) 
+				if (!class_exists($helpers))
 				{
 					throw new InvalidHelperManagerException(\JText::sprintf(
 						'Invalid helper manager class provided (%s)',
@@ -737,7 +736,7 @@ class View extends Object
 				$helpers = new $helpers();
 			}
 
-			if (!$helpers instanceof HelperManager) 
+			if (!$helpers instanceof HelperManager)
 			{
 				throw new InvalidHelperManagerException(\JText::sprintf(
 					'Helper manager must extend Hubzero\View\HelperManager; got type "%s" instead',
@@ -780,7 +779,7 @@ class View extends Object
 	 */
 	/*public function view($layout=null, $name=null)
 	{
-		if (!$layout) 
+		if (!$layout)
 		{
 			throw new \InvalidArgumentException(
 				'Either a view object or layout name must be provided.'
@@ -788,7 +787,7 @@ class View extends Object
 		}
 
 		// If we were passed only a view object, just return it.
-		if ($layout instanceof View) 
+		if ($layout instanceof View)
 		{
 			return $layout;
 		}
