@@ -402,6 +402,7 @@ HUB.ProjectFiles = {
 			{
 				$('#status-msg').css({'opacity':100});
 				$('#status-msg').html('<p class="witherror">' + response.error + '</p>');
+				$('#sync-wrap').removeClass('syncing');
 			}
 			else if (response.message && !response.auto)
 			{
@@ -562,7 +563,8 @@ HUB.ProjectFiles = {
 				 && connected == true) 
 			{
 				var href = $(item).attr('href');
-				if (href.search('&no_html=1') == -1) {
+				if (href.search('&no_html=1') == -1) 
+				{
 					href = href + '&no_html=1';
 				}
 				if (href.search('&ajax=1') == -1) {
@@ -925,10 +927,21 @@ HUB.ProjectFiles = {
 		// Confirm directory deletion
 		if ($('#disconnect') && HUB.Projects) {
 			$('#disconnect').on('click', function(e) {
-				e.preventDefault();			
-				HUB.Projects.addConfirm($('#disconnect'), 
-				'Are you sure you want to disconnect project from this service?', 
-				'Yes, disconnect and remove remote data', 'No, do not disconnect');
+				e.preventDefault();		
+				
+				if ($('#disconnect').parent().hasClass('creator'))
+				{
+					HUB.Projects.addConfirm($('#disconnect'), 
+					'Are you sure you want to disconnect project from this service?', 
+					'Yes, disconnect and remove remote data', 'No, do not disconnect');	
+				}
+				else
+				{
+					HUB.Projects.addConfirm($('#disconnect'), 
+					'Are you sure you want to disconnect this gmail account from this project?', 
+					'Yes, disconnect', 'No, do not disconnect');
+				}	
+				
 			});
 		}
 	},
